# Fief client for Python

[![build](https://github.com/fief-dev/fief-python/workflows/Build/badge.svg)](https://github.com/fief-dev/fief-python/actions)
[![codecov](https://codecov.io/gh/fief-dev/fief-python/branch/main/graph/badge.svg)](https://codecov.io/gh/fief-dev/fief-python)
[![PyPI version](https://badge.fury.io/py/fief-client.svg)](https://badge.fury.io/py/fief-client)

## Installation

```
pip install fief-client
```

## Getting started

* Official website: [https://www.fief.dev](https://www.fief.dev)
* Documentation: [https://docs.fief.dev](https://docs.fief.dev)

## Contributing

All contributions to improve the project are welcome! In particular, bug and documentation fixes are really appreciated.

For new features and larger improvements, we kindly ask you to [**open a discussion first**](https://github.com/orgs/fief-dev/discussions/new?category=ideas) about your idea, what motivates it and how you plan to implement it **before you start working**. It'll avoid frustration on both sides if we decide not to integrate your code in the project.

## License

MIT
